
# Type: filler


The value in a property-value tuple

URI: [biolink:filler](https://w3id.org/biolink/vocab/filler)


## Domain and Range

[NamedThing](NamedThing.md) ->  <sub>OPT</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [node property](node_property.md)

## Children


## Used by

 * [NamedThing](NamedThing.md)
